@@ -32,46 +32,43 @@ extern zend_module_entry taint_module_entry;
 #include "TSRM.h"
 #endif
 
-#define PHP_TAINT_VERSION "2.0.4"
+#define PHP_TAINT_VERSION "2.0.5"
 
 /* it's important that make sure 
  * this value is not used by Zend or
  * any other extension agianst string */
 #define IS_STR_TAINT_POSSIBLE    (1<<7)
 
-#if PHP_VERSION_ID > 70000 
-# if PHP_VERSION_ID < 70100
-# define PHP_7_0  1
-# define PHP_7_1  0
-# elif PHP_VERSION_ID < 70200
-# define PHP_7_0  0
-# define PHP_7_1  1
-# elif PHP_VERSION_ID < 70300
-# undef IS_STR_TAINT_POSSIBLE
-/* Coflicts with GC_COLLECTABLE which is introduced in 7.2 */
-# define IS_STR_TAINT_POSSIBLE (1<<6)
-# define PHP_7_0  0
-# define PHP_7_1  2
+#if PHP_VERSION_ID >= 70000
+# if PHP_VERSION_ID >= 70200
+#  undef IS_STR_TAINT_POSSIBLE
+   /* Coflicts with GC_COLLECTABLE which is introduced in 7.2 */
+#  define IS_STR_TAINT_POSSIBLE (1<<6)
+# endif
+# if PHP_VERSION_ID >=70300
+#  define EX_CONSTANT(op) RT_CONSTANT(EX(opline), op)
+#  undef IS_STR_TAINT_POSSIBLE
+#  define IS_STR_TAINT_POSSIBLE (1<<5) /* GC_PROTECTED */
+#  define TAINT_MARK(str)     GC_ADD_FLAGS(str, IS_STR_TAINT_POSSIBLE)
+#  define TAINT_POSSIBLE(str) (GC_FLAGS((str)) & IS_STR_TAINT_POSSIBLE)
+#  define TAINT_CLEAN(str)    GC_DEL_FLAGS(str, IS_STR_TAINT_POSSIBLE)
 # else
-# error "Unsupported PHP Version ID:" PHP_VERSION_ID
+#  define TAINT_MARK(str)     (GC_FLAGS((str)) |= IS_STR_TAINT_POSSIBLE)
+#  define TAINT_POSSIBLE(str) (GC_FLAGS((str)) & IS_STR_TAINT_POSSIBLE)
+#  define TAINT_CLEAN(str)    (GC_FLAGS((str)) &= ~IS_STR_TAINT_POSSIBLE)
 # endif
 #else
 # error "Unsupported PHP Version ID:" PHP_VERSION_ID
 #endif
 
-#define TAINT_MARK(str)		(GC_FLAGS((str)) |= IS_STR_TAINT_POSSIBLE)
-#define TAINT_POSSIBLE(str) (GC_FLAGS((str)) & IS_STR_TAINT_POSSIBLE)
-#define TAINT_CLEAN(str)  	(GC_FLAGS((str)) &= ~IS_STR_TAINT_POSSIBLE)
-
 #define TAINT_OP1_TYPE(opline)	(opline->op1_type)
 #define TAINT_OP2_TYPE(opline)	(opline->op2_type)
 
-
-#if PHP_7_0
+#if PHP_VERSION_ID < 70100
 #define TAINT_RET_USED(opline) (!((opline)->result_type & EXT_TYPE_UNUSED))
 #define TAINT_ISERR(var)       (var == &EG(error_zval))
 #define TAINT_ERR_ZVAL(var)    (var = &EG(error_zval))
-#elif PHP_7_1 
+#else
 #define TAINT_RET_USED(opline) ((opline)->result_type != IS_UNUSED)
 #define TAINT_ISERR(var)       (Z_ISERROR_P(var))
 #define TAINT_ERR_ZVAL(var)    (ZVAL_ERROR(var))
@@ -108,7 +105,11 @@ PHP_FUNCTION(taint_dirname);
 PHP_FUNCTION(taint_basename);
 PHP_FUNCTION(taint_pathinfo);
 
+#if PHP_VERSION_ID >= 70300
+typedef zif_handler php_func;
+#else
 typedef void (*php_func)(INTERNAL_FUNCTION_PARAMETERS);
+#endif
 
 ZEND_BEGIN_MODULE_GLOBALS(taint)
 	zend_bool enable;
